Telescope Control Library

Dependents:   PushToGo-F429

Revision:
10:e356188d208e
Parent:
9:d0413a9b1386
--- a/Axis.h	Mon Sep 10 02:41:05 2018 -0400
+++ b/Axis.h	Fri Sep 14 01:30:55 2018 -0400
@@ -7,9 +7,6 @@
 
 #ifndef PUSHTOGO_AXIS_H_
 #define PUSHTOGO_AXIS_H_
-
-class Axis;
-
 #include "StepperMotor.h"
 #include <math.h>
 #include "mbed.h"
@@ -57,6 +54,8 @@
 	FINISH_ERROR = 4
 } finishstate_t;
 
+class PEC;
+
 /** General Rotating Axis class
  * Handles low-level stepper timing, calculates the speed and distance to rotate
  * API provides comprehensive slewing, tracking and guiding.
@@ -281,14 +280,14 @@
 		return status;
 	}
 
 	/** Returns the current slew speed
 	 */
 	double getSlewSpeed() const
 	{
 		return slewSpeed;
 	}
 
 	/** Set slew speed of the axis
 	 * @param new slew speed in deg/s
 	 * @note Can now be called when a indefinite slew is in progress. 
 	 * @note If called during a target slew, the speed will be updated on the next slew
@@ -407,7 +406,7 @@
 	/*Runtime values*/
 	volatile double currentSpeed; /// Current speed in deg/s
 	volatile axisrotdir_t currentDirection; // Current direction
-	double slewSpeed; /// Slewing speed in deg/s
+	double slewSpeed; /// Slewing speed in deg/s (only for indefinite slew)
 	double trackSpeed; /// Tracking speed in deg/s (no accel/deceleration)
 	double guideSpeed; /// Guide speed in deg/s. this amount will be subtracted/added to the trackSpeed
 	volatile axisstatus_t status; /// State of the axis
@@ -281,14 +280,14 @@
 	}
 
-	/** Returns the current slew speed
+	/** Returns the current slew speed (only for indefinite slew)
 	 */
 	double getSlewSpeed() const
@@ -281,14 +280,14 @@
 	}
 
-	/** Set slew speed of the axis
+	/** Set slew speed of the axis (only for indefinite slew)
 	 * @param new slew speed in deg/s
 	 * @note Can now be called when a indefinite slew is in progress. 